/**
 * DGC业务逻辑公共方法以及公共枚举
 * @since SDK1.2
 */
DGC.Helper = {

    /**
     * 公共枚举声明
     */
    ATTR:{

        /*FeedAPI枚举*/
        /*性别*/
        GENDER:{
            SECRET: 0,
            MALE :  1,
            FEMALE : 2
        },
        /*SNS绑定过的字段值*/
        BIND_KEY:{
            SINA:'sina',
            RENREN: 'renren',
            QQ: 'tencent'
        },
        /*绑定/登录SNS*/
        BIND_SNS:{
            SINA : 1,
            RENREN : 2,
            QQ: 4
        },
        /*同步SNS枚举*/
        SYNC_SNS:{
            SINA: 1,
            RENREN: 2,
            QQ: 4
        },
        /*同步操作类型*/
        SYNC_TYPE:{
            ALL: 1,
            AVATAR: 2,
            NAME: 3
        },
        /*获取成就发信息SNS*/
        ACHIEVE_SNS:{
            SINA : 1,
            RENREN : 2,
            QQ: 4
        },
        /*取消绑定SNS*/
        UNBIND_SNS:{
            SINA : 1,
            RENREN : 2,
            QQ: 4
        },
        /*SDK枚举*/
        UPDATE_AVATAR : {
            CAMERA : 1,
            LOCAL : 2
        },
        /**
         * 登录窗口模式枚举(客户端)
         */
        USER_LOGIN_DIALOG : {
            LOGIN : 0, /*登录窗口*/
            SWITCH : 1 /*切换账号窗口*/
        }

    },

    /**
     * 公共业务方法声明
     */

    /**
     * 判断是否为自己
     * @param {String} id
     */
    isMe: function(id){
        return (id == window.sdk.player.id);
    },

    /**
     * 是否支持乐币
     */
    isSupportCoins: function(){
        return window.sdk.channel.enable_coin_payment;
    },

    /**
     * 是否支持成就和排行榜
     */
    isSupportHighscoresAchieve: function(){
        return window.sdk.achievementsState || window.sdk.highScoresState; //任意支持，则全支持
    },

    /**
     * 是否支持积分墙
     */
    isSupportIntegral : function(){
        return window.sdk.integralState;
    },

    /**
     * 是否支持活动
     */
    isSupportActivities:function(){
        return window.sdk.activitiesState;
    },

    /**
     * 是否支持兑换码
     */
    isSupportPromotion: function(){
        return window.sdk.promotionState;
    },

    /**
     * 判断玩家是否绑定过任意SNS
     */
    isAnySNSBound : function(){
        var KEY = this.ATTR.BIND_KEY;
        return this.isSNSBound(KEY.QQ) || this.isSNSBound(KEY.SINA) || this.isSNSBound(KEY.RENREN) ;
    },

    /**
     * 判断玩家是否绑定指定SNS
     * @param {String} snsKey 绑定后字段标识  ATTR.BIND_KEY
     */
    isSNSBound : function(snsKey){
        return  window.sdk[snsKey] != null;
    },

    /**
     * 判断玩家已绑定指定SNS是否过期
     * @param {String} snsKey 绑定后字段标识 ATTR.BIND_KEY
     */
    isSNSExpried : function(snsKey){
        if(this.isSNSBound(snsKey)){
            return window.sdk[snsKey].expired;
        }
        return false;
    },

    /**
     * 判断是否已经设置密码
     */
    isPasswordSet: function(){
        return window.sdk.player.has_password;
    },

    /**
     * 判断当前是否绑定手机
     */
    isPhoneBound : function(){
        return !$.isEmpty(window.sdk.security.phone);
    },

    /**
     * SDK推荐头像信息
     */
    isSDKAvatarsReady : function(){
        //获取当前Avatar信息
        return DGC.Common.getAppConfig("cacheavatars") && window.sdk.avatarVerified;
    }

}

/**
 * 全局命名空间
 */
window.DH = DGC.Helper;