/**
 * 开发者购买自定义商品
 */
DGC.View.DeveloperPayUser =  $.inherits(DGC.View, {

    baseId: 'nativepayuser-view',

    /**
     * 页面无内容
     */
    isDeferRender: false,

    /**
     * 剩余乐币
     */
    playerCoins: undefined,

    /**
     * 是否支持乐币
     */
    enableCoins: undefined,

    /**
     * 订单信息
     */
    orderInfo: undefined,

    /**
     * 道具类型自定义道具类型
     * 0:普通道具Order
     * 1:CheckPoint
     * 2:CheckPoint Group
     * @type Number
     */
    type: 0 ,

    viewReady: function(){
        DGC.ActionUtil.fullScreen(true);
        DGC.ActionUtil.transparentBG();

        //显示窗口需要的数据源
        this.requestAPI = {
            orderReady: true //道具信息
        };

        //支持乐币支付，非离线模式则查询当前余额
        if(window.sdk.channel.enable_coin_payment && !window.sdk.isOffline && this.type != 2 /*非CheckPoint group类型*/){
            $.extend(this.requestAPI, { coinsReady: false });
            this.action.model['pay'].queryPlayerCoins( false );
        }else{
            this.directToBuy();
        }
    },

    /**
     * 保存用户剩余乐币数
     * @param {Number} coins 乐币数
     * @param {Boolean} enable 是否支持乐币
     */
    cachePlayerCoins: function(coins){
        //乐币数
        this.playerCoins = window.sdk.player.coins = coins;
        $.extend(this.requestAPI, { coinsReady: true });

        this.directToBuy();
    },

    /**
     * 判断所有请求是否都已经响应
     */
    isAPIReady : function(){
        for(var key in this.requestAPI){
            if(!this.requestAPI[key]){
                return false;
            }
        }
        return true;
    },

    /**
     * 判断根据乐币和道具信息支付方式
     */
    directToBuy: function(){
        //未加载完成，无需判断
        if(!this.isAPIReady()){
            return false;
        }

        var quantity = this.orderInfo.quantity || 1 /*默认开发者入口只能购买一个道具*/,
            context = this;

        //防止开发者不给数量值
        $.extend(this.orderInfo, { "quantity": quantity } );

        context.buyAction();
    },

    /**
     * 购买道具逻辑
     */
    buyAction: function(){
        //道具列表
        if(window.sdk.isOffline){
            this.action.setView("OfflineCharge",{
                orderInfo: this.orderInfo
            }, false /*不重置视图*/, true /*不保存当前视图*/);
        }else {
             switch(this.type){
                case 0 /*普通道具*/:
                    //启用乐币支付且乐币足够
                    if(window.sdk.channel.enable_coin_payment && this.isEnoughCoins() ){
                        this.action.model['pay'].executePay(0 /*乐币支付*/, {
                            orderInfo: this.orderInfo
                        });
                    }else{
                        this.switchToChargeList();
                    }
                    break;
                case 1 /*CheckPoint*/:
                    //启用乐币支付且乐币足够
                    if(window.sdk.channel.enable_coin_payment && this.isEnoughCoins() ){
                        this.action.model['pay'].executePay(10 /*乐币支付*/, {
                            orderInfo: this.orderInfo
                        });
                    }else{
                        this.switchToChargeList();
                    }
                    break;
                case 2 /*CheckPoint Group*/:
                    this.switchToChargeList(); //仅支付RMB支付
                    break;
            }
        }
    },

    /**
     * 切换到充值/支付列表
     */
    switchToChargeList : function(){
        //进入支付列表
        this.action.setView("ChargeAccount",{
            chargeModel: 1 /*开发者界面进入支付列表*/,
            orderInfo: this.orderInfo,
            type: this.type
        }, false /*不重置视图*/, true /*不保存当前视图*/);
    },

    /**
     * 判断当前乐币是否能购买道具
     */
    isEnoughCoins : function(){
        var price;
        switch(this.type){
           case 0 /*道具*/:
               price = this.orderInfo.item.product.price;
               break;
           case 1 /*CheckPoint*/:
               price = this.orderInfo.price;
               break;
        }

        return this.playerCoins >= (price * this.orderInfo.quantity);
    },

    /**
     * 通知SDK更新游戏道具信息
     * @param {Object} payResult 支付结果
     * @param {Object} detail 支付结果详情
     * @param {Object} failitem 支付失败的item对象
     * */
    showLedouPayResult : function(result, detail , failitem ){
        var DAU = DGC.ActionUtil;
        this.action.model['pay'].payOrderNotify(0 /*乐币方式购买*/ , result, detail , failitem, function(){
            DGC.ActionUtil.showTipMsg($.format(resName.TIP_LEDOUSHOP_LEDOU_BUY_SUCCESS,[detail.product.name, detail.amount]));
        });

        //返回游戏
        DAU.returnToGame();
    },

    /**
     * 通知SDK更新CheckPoint信息
     * @param {Object} payResult 支付结果
     * @param {Object} detail 支付结果详情
     * @param {Object} failitem 支付失败的item对象
     * */
    payCPByLeDouResult : function(result, detail , failitem){
        this.action.model['pay'].payOrderNotify( 10 /*乐币购买CheckPoint*/ , result, detail , failitem, this.returnToGameAction);
    },

    /**
     * 当该页面请求超时，点击确认，直接返回游戏
     */
    returnToGameAction: function(){
        //返回游戏
        DGC.ActionUtil.returnToGame();
    }

});