/**
 * 开发者使用兑换码
 */
DGC.View.DeveloperPromote = $.inherits(DGC.View, {

    baseId: 'nativepromote-view',

    /**
     * 页面无内容
     */
    isDeferRender: false,

    /**
     * 本地兑换KEY
     */
    promoteCodeKey : 'PROMOTE_CODE_ENTER_COUNT',

    //兑换码输入次数限制
    promoteCodeEnterLimit : 5,

    //兑换码输入限制的过期时间,单位毫秒数
    promoteCodeExpiredTime : 7200000,

    //上次请求的锁定数据
    lastPromoteData: undefined,

    /**
     * 兑换码
     */
    promoteCode: undefined,

    /**
     * 订单对象(自定义商品)
     */
    orderInfo: undefined,

    viewReady: function(){
        DGC.ActionUtil.fullScreen(true);
        DGC.ActionUtil.transparentBG();

        var DC = DGC.Common,
            promoteCodeData = DC.getAppConfig(this.promoteCodeKey, true),
            meModel  = this.action.model['me'];

        /**
         * 返回方法
         */
        this.backFn = function(){
            DGC.ActionUtil.returnToGame();
        };

        var args = [ this.promoteCode ];
        //可选参数
        if(this.orderInfo){
            args.push(this.orderInfo.item.product);
        }

        //取数据
        var currTimestamp = new Date().getTime(),
            promoteCodeData = promoteCodeData || { 'count' : 0,  'timestamp' : currTimestamp };

        if(promoteCodeData.count == this.promoteCodeEnterLimit) {//判断两个小时内输入超过5次
            if((currTimestamp - promoteCodeData.timestamp) > this.promoteCodeExpiredTime) { //锁定超过2小时
                 DC.removeAppConfig(this.promoteCodeKey, true); //清空数据
                 //达到上限次数，超过2小时，清零兑换
                 meModel.updatePromotionCode.apply(meModel, args);
            }else{
                DGC.ActionUtil.showTipMsg(resName.TIP_PROMOTECODE_ENTER_MORE_THAN_FIVE,
                    $.bindFn(this.promoteFailBack, this, [ 3006 /*5次上限锁定*/, resName.TIP_PROMOTECODE_ENTER_MORE_THAN_FIVE ]));
                return false;
            }
        //未达上次次数直接兑换
        }else{
             this.lastPromoteData = promoteCodeData; //当期缓存次数
             meModel.updatePromotionCode.apply(meModel, args);
        }
    },

    /**
     * 兑换结果回调
     */
    handlePromoteCode: function(rs){
        var DAU = DGC.ActionUtil,
            data = rs.data,
            CM = DGC.Common,
            context = this;


        if(!data.err_code) {//兑换成功
            //请求成功后，重置次数
            DGC.Common.removeAppConfig(context.promoteCodeKey, true);

            if(data.promotion_type) {//兑换码类型(1:乐币 2:道具 3:游戏)
                if(data.promotion_type == 1) {//乐币
                    DAU.showTipMsg($.format(resName.TIP_PROMOTECODE_COIN_SUCCESS, [data.coins]), this.backFn);
                } else if(data.promotion_type == 2) {//道具
                    //购买道具
                    DAU.showTipMsg($.format(resName.TIP_PROMOTECODE_PRODUCT_SUCCESS, [data.game.name, 1, data.product.name]), function() {
                        //优先取自定义道具
                        var product = context.orderInfo ? context.orderInfo.item.product : data.product;
                        DAU.notifySDKBuyResult(100 /*兑换码方式*/, true, { product: product , quantity : 1 });//购买道具状态通知SDK
                        DGC.ActionUtil.returnToGame();
                    });
                } else if(data.promotion_type == 3) {//游戏

                }
            }
        } else {//兑换失败

            if(data.err_code == 3001) {//推广码不存在
                var lastPromote = this.lastPromoteData || { 'count' : 0,  'timestamp' : new Date().getTime() };
                lastPromote.count += 1;

                //不存在兑换码
                CM.setAppConfig(this.promoteCodeKey, lastPromote , true);
                DAU.showTipMsg(resName.TIP_PROMOTECODE_NOT_EXIST,
                    $.bindFn(this.promoteFailBack, this, [data.err_code, resName.TIP_PROMOTECODE_NOT_EXIST ]));
            } else if(data.err_code == 3002) {//游戏不匹配
                this.gameInfo = data.game;
                DGC.ActionUtil.getGameState([this.gameInfo.bundle_id]);
            } else if(data.err_code == 3003) {//推广码过期
                DAU.showTipMsg(resName.TIP_PROMOTECODE_EXPIRED,
                    $.bindFn(this.promoteFailBack, this, [data.err_code, resName.TIP_PROMOTECODE_EXPIRED ]));
            } else if(data.err_code == 3004) {//已拥有该道具
                DAU.showTipMsg(resName.TIP_PROMOTECODE_HAS_OWN,
                    $.bindFn(this.promoteFailBack, this, [data.err_code, resName.TIP_PROMOTECODE_HAS_OWN ]));
            } else if(data.err_code == 3005){ //该兑换码已经被使用
                DAU.showTipMsg(resName.TIP_PROMOTECODE_USED,
                     $.bindFn(this.promoteFailBack, this, [data.err_code, resName.TIP_PROMOTECODE_USED ]));
            } else if(data.err_code == 3006){ //服务端5次上限
                DAU.showTipMsg(resName.TIP_PROMOTECODE_ENTER_MORE_THAN_FIVE,
                    $.bindFn(this.promoteFailBack, this, [data.err_code, resName.TIP_PROMOTECODE_ENTER_MORE_THAN_FIVE ]));
            } else if(data.err_code == 3007){ //兑换码价钱不符
                DAU.showTipMsg(resName.TIP_PROMOTECODE_NOT_MATCH_PRODUCT,
                    $.bindFn(this.promoteFailBack, this, [data.err_code, resName.TIP_PROMOTECODE_NOT_MATCH_PRODUCT ]));
            }else if(data.err_code == 3008){ //兑换码类型不正确
                 DAU.showTipMsg(resName.TIP_PROMOTECODE_NOT_MATCH_TYPE,
                    $.bindFn(this.promoteFailBack, this, [data.err_code, resName.TIP_PROMOTECODE_NOT_MATCH_TYPE ]));
            }else{
                if(!$.isEmpty(data.err_detail)){
                    DAU.showTipMsg(data.err_detail);
                }
            }
        }
    },

    /**
     * 显示当前游戏的状态
     */
    showGameStatus : function(result) {
        var status = result.data.states[0],
            DAU = DGC.ActionUtil,
            game = this.gameInfo;

        if(status) {
            DAU.showTipMsg($.format(resName.TIP_PROMOTECODE_GAME_NOT_MATCH, [game.name]), function() {
                DAU.startGame(game.bundle_id);//启动游戏
                DAU.returnToGame();
            });
        } else {
            DAU.showTipMsg($.format(resName.TIP_PROMOTECODE_NEED_DOWNLOAD, [game.name]), function() {
                DAU.download(game.download_url, game.bundle_id);//下载游戏
                DAU.returnToGame();
            });
        }
    },

    /**
     * 使用兑换码失败通知SDK
     */
    promoteFailBack : function(code , detail){
        var item = this.orderInfo ?  { product: this.orderInfo.item.product , quantity : 1 } : {};
        DGC.ActionUtil.notifySDKBuyResult(100 /*兑换码方式*/, false,  item ,  code, detail);//购买道具状态通知SDK
        this.backFn.call(this);
    },


    /**
     * 当该页面请求超时，点击确认，直接返回游戏
     */
    returnToGameAction: function(){
        //返回游戏
        this.backFn.call(this);
    }
});